@@ -163,6 +163,8 @@ int main(int argc, char *argv[])
 	char bind_to_valid = 0;
 	char split = 0;
 
+	signal(SIGPIPE, SIG_IGN);
+
 	if (page_size == -1)
 		page_size = 4096;
 
@@ -186,7 +188,7 @@ int main(int argc, char *argv[])
 
 					if (dummy)
 					{
-						bind_to.sin_port = atoi(dummy + 1);
+						bind_to.sin_port = htons(atoi(dummy + 1));
 						*dummy = 0x00;
 					}
 
@@ -472,7 +474,7 @@ int main(int argc, char *argv[])
 		{
 			char *fp = NULL;
 			int rc;
-			char *sc = NULL;
+			char *sc = NULL, *scdummy = NULL;
 
 			curncount++;
 
@@ -595,8 +597,7 @@ int main(int argc, char *argv[])
 					char *dummy = strchr(encoding + 1, '\n');
 					if (dummy) *dummy = 0x00;
 
-					if (strstr(encoding, "gzip") == 0 ||
-							strstr(encoding, "deflate") == 0)
+					if (strstr(encoding, "gzip") == 0 || strstr(encoding, "deflate") == 0)
 					{
 						is_compressed = 1;
 					}
@@ -687,9 +688,13 @@ int main(int argc, char *argv[])
 					if (dummy) *dummy = 0x00;
 
 					if (strstr(ok_str, sc))
+					{
 						printf("%f", ms);
+					}
 					else
+					{
 						printf("%s", err_str);
+					}
 
 					if (show_statuscodes)
 						printf(" %s", sc);
@@ -737,6 +742,18 @@ int main(int argc, char *argv[])
 				printf("\n");
 			}
 
+			if (show_statuscodes && ok_str != NULL && sc != NULL)
+			{
+				scdummy = strchr(sc, ' ');
+				if (scdummy) *scdummy = 0x00;
+
+				if (strstr(ok_str, sc) == NULL)
+				{
+					ok--;
+					err++;
+				}
+			}
+
 			free(sc);
 
 			break;
@@ -751,6 +768,7 @@ int main(int argc, char *argv[])
 	if (!quiet && !machine_readable && !nagios_mode)
 	{
 		printf("--- %s ping statistics ---\n", get);
+
 		if (count == -1)
 			printf("%d connects, %d ok, %3.2f%% failed\n", curncount, ok, (((double)err) / ((double)curncount)) * 100.0);
 		else
