@@ -49,6 +49,15 @@ int connect_to(struct sockaddr *bind_to, struct sockaddr_in *addr, int portnr, i
 	/* go through a specific interface? */
 	if (bind_to)
 	{
+		int set = 1;
+
+		/* set reuse flags */
+		if (setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, &set, sizeof(set)) == -1)
+		{
+			snprintf(last_error, ERROR_BUFFER_SIZE, "error setting sockopt to interface (%s)", strerror(errno));
+			return -1;
+		}
+
 		if (bind(fd, bind_to, sizeof(*bind_to)) == -1)
 		{
 			snprintf(last_error, ERROR_BUFFER_SIZE, "error binding to interface (%s)", strerror(errno));
@@ -91,7 +100,7 @@ int connect_to(struct sockaddr *bind_to, struct sockaddr_in *addr, int portnr, i
 	else
 	{
 		int optval=0;
-		int optvallen=sizeof(optval);
+		socklen_t optvallen=sizeof(optval);
 
 		/* see if the connect succeeded or failed */
 		if (getsockopt(fd, SOL_SOCKET, SO_ERROR, &optval, &optvallen) == -1)
